@@ -1,3 +1,4 @@
+import { defineMessages, FormattedMessage, injectIntl } from 'react-intl';
 import React from 'react';
 import ImmutablePropTypes from 'react-immutable-proptypes';
 import { Link } from 'react-router';
@@ -6,22 +7,39 @@ import DeleteStackButton from './DeleteStackButton';
 import InlineNotification from '../ui/InlineNotification';
 import { deploymentStatusMessages } from '../../constants/StacksConstants';
 
-export default class DeploymentFailure extends React.Component {
+const messages = defineMessages({
+  deleteDeployment: {
+    id: 'DeploymentFailure.deleteDeployment',
+    defaultMessage: 'Delete Deployment'
+  },
+  moreDetails: {
+    id: 'DeploymentFailure.moreDetails',
+    defaultMessage: 'More details'
+  },
+  requestingDeletion: {
+    id: 'DeploymentFailure.requestingDeletion',
+    defaultMessage: 'Requesting Deletion of Deployment'
+  }
+});
+
+class DeploymentFailure extends React.Component {
   render() {
+    const { formatMessage } = this.props.intl;
+
     return (
       <div>
         <InlineNotification type="error"
                             title={deploymentStatusMessages[this.props.stack.stack_status]}>
           <p>
             {this.props.stack.stack_status_reason} <Link to="/deployment-plan/deployment-detail">
-            More details</Link>
+            <FormattedMessage {...messages.moreDetails}/></Link>
           </p>
         </InlineNotification>
-        <DeleteStackButton content="Delete Deployment"
+        <DeleteStackButton content={formatMessage(messages.deleteDeployment)}
                            deleteStack={this.props.deleteStack}
                            disabled={this.props.isRequestingStackDelete}
                            loaded={!this.props.isRequestingStackDelete}
-                           loaderContent="Requesting Deletion of Deployment"
+                           loaderContent={formatMessage(messages.requestingDeletion)}
                            stack={this.props.stack}/>
       </div>
     );
@@ -30,6 +48,9 @@ export default class DeploymentFailure extends React.Component {
 
 DeploymentFailure.propTypes = {
   deleteStack: React.PropTypes.func.isRequired,
+  intl: React.PropTypes.object,
   isRequestingStackDelete: React.PropTypes.bool,
   stack: ImmutablePropTypes.record.isRequired
 };
+
+export default injectIntl(DeploymentFailure);
