@@ -1,13 +1,21 @@
+import { defineMessages, injectIntl } from 'react-intl';
 import React from 'react';
-import { Map, List } from 'immutable';
-import ImmutablePropTypes from 'react-immutable-proptypes';
+import { isObjectLike } from 'lodash';
 
 import HorizontalInput from '../ui/forms/HorizontalInput';
+import HorizontalNumberInput from '../ui/forms/HorizontalNumberInput';
 import HorizontalTextarea from '../ui/forms/HorizontalTextarea';
 import HorizontalCheckBox from '../ui/forms/HorizontalCheckBox';
 import HorizontalStaticText from '../ui/forms/HorizontalStaticText';
 
-export default class ParameterInput extends React.Component {
+const messages = defineMessages({
+  enterValidJson: {
+    id: 'ParameterInput.enterValidJson',
+    defaultMessage: 'Please enter a valid JSON string.'
+  }
+});
+
+class ParameterInput extends React.Component {
   /**
   * Process the parameter, generate relevant input
   */
@@ -15,26 +23,19 @@ export default class ParameterInput extends React.Component {
     const { name, label, description, defaultValue, value, type } = this.props;
     if(value) {
       return (
-        <HorizontalStaticText text={value}
+        <HorizontalStaticText text={isObjectLike(value) ? JSON.stringify(value) : value}
                               title={label}
                               labelColumnClasses="col-sm-4"
                               inputColumnClasses="col-sm-8"/>
       );
-    } else if (type.toLowerCase() === 'json' || Map.isMap(defaultValue)) {
+    } else if (type.toLowerCase() === 'json' || isObjectLike(defaultValue)) {
       return (
         <HorizontalTextarea name={name}
                             title={label}
                             description={description}
-                            value={defaultValue ? JSON.stringify(defaultValue.toJS()) : ''}
-                            labelColumnClasses="col-sm-4"
-                            inputColumnClasses="col-sm-8"/>
-      );
-    } else if (type.toLowerCase() === 'commadelimitedlist' && List.isList(defaultValue)) {
-      return (
-        <HorizontalTextarea name={name}
-                            title={label}
-                            description={description}
-                            value={defaultValue.toJS()}
+                            value={defaultValue ? JSON.stringify(defaultValue) : ''}
+                            validations="isJson"
+                            validationError={this.props.intl.formatMessage(messages.enterValidJson)}
                             labelColumnClasses="col-sm-4"
                             inputColumnClasses="col-sm-8"/>
       );
@@ -47,26 +48,25 @@ export default class ParameterInput extends React.Component {
                             labelColumnClasses="col-sm-4"
                             inputColumnClasses="col-sm-8"/>
       );
-    } else if(type.toLowerCase() === 'String' &&
+    } else if(type.toLowerCase() === 'string' &&
               /^.*(Key|Cert|Certificate)$/.test(name)) {
       return (
         <HorizontalTextarea name={name}
                             title={label}
                             description={description}
-                            value={defaultValue.toJS()}
+                            value={defaultValue}
                             labelColumnClasses="col-sm-4"
                             inputColumnClasses="col-sm-8"/>
       );
     } else if(type.toLowerCase() === 'number') {
       return (
-        <HorizontalInput name={name}
-                         title={label}
-                         type="number"
-                         min={0}
-                         description={description}
-                         value={defaultValue}
-                         labelColumnClasses="col-sm-4"
-                         inputColumnClasses="col-sm-8"/>
+        <HorizontalNumberInput name={name}
+                               title={label}
+                               min={0}
+                               description={description}
+                               value={defaultValue}
+                               labelColumnClasses="col-sm-4"
+                               inputColumnClasses="col-sm-8"/>
       );
     } else if(type.toLowerCase() === 'boolean') {
       return (
@@ -93,18 +93,27 @@ export default class ParameterInput extends React.Component {
 
 ParameterInput.propTypes = {
   defaultValue: React.PropTypes.oneOfType([
-    ImmutablePropTypes.list,
-    ImmutablePropTypes.map,
+    React.PropTypes.object,
+    React.PropTypes.array,
     React.PropTypes.bool,
     React.PropTypes.number,
     React.PropTypes.string
-  ]).isRequired,
+  ]),
   description: React.PropTypes.string.isRequired,
+  intl: React.PropTypes.object,
   label: React.PropTypes.string.isRequired,
   name: React.PropTypes.string.isRequired,
   type: React.PropTypes.string.isRequired,
-  value: React.PropTypes.string
+  value: React.PropTypes.oneOfType([
+    React.PropTypes.object,
+    React.PropTypes.array,
+    React.PropTypes.bool,
+    React.PropTypes.number,
+    React.PropTypes.string
+  ])
 };
 ParameterInput.defaultProps = {
   defaultValue: ''
 };
+
+export default injectIntl(ParameterInput);
