@@ -1,5 +1,5 @@
 import { connect } from 'react-redux';
-import { defineMessages, FormattedMessage } from 'react-intl';
+import { defineMessages, FormattedMessage, injectIntl } from 'react-intl';
 import { Link } from 'react-router';
 import ImmutablePropTypes from 'react-immutable-proptypes';
 import React from 'react';
@@ -38,7 +38,7 @@ const messages = defineMessages({
   },
   noPlans: {
     id: 'ListPlans.noPlans',
-    defaultMessage: 'There are currently no plans'
+    defaultMessage: 'There are currently no plans.'
   },
   createNewPlan: {
     id: 'ListPlans.createNewPlan',
@@ -79,7 +79,7 @@ class ListPlans extends React.Component {
     return (
       <Link to="/plans/new"
             query={{tab: 'newPlan'}}
-            className="btn btn-primary">
+            className="btn btn-primary"
             id="ListPlans__newPlanLink">
         <span className="fa fa-plus"/>  <FormattedMessage {...messages.createNewPlan}/>
       </Link>
@@ -145,7 +145,7 @@ function mapDispatchToProps(dispatch) {
   };
 }
 
-export default connect(mapStateToProps, mapDispatchToProps)(ListPlans);
+export default injectIntl(connect(mapStateToProps, mapDispatchToProps)(ListPlans));
 
 class RowActionsCell extends React.Component {
   render() {
